package org.xdv.clx.expr;

import org.xdv.xpath.XPathExpression;

/**
 * RULES/KEY - CLX element implementation.
 * <br>
 * It is kind of map that allows to access elements using key.
 * 
 * @see <a href="http://www.clixml.org/clix/1.0/#rules.schema">CLiXML - clix:key</a>
 * @see org.xdv.clx.base.ClxConstants#TAG_KEY
 * @author Tomasz Kokoszka
 */
public class ClxKey {
    
    /** Map name; !=null */
    private final String name;
    
    /** Key in map - absolute XPath query to select keys; !=null */
    private final XPathExpression match;
    
    /** Value in map - relative XPath query to select key value; !=null */
    private final XPathExpression use;
    
    /**
     * Create a new map.
     * @param name map name
     * @param match key in map - absolute XPath query to select keys
     * @param use value in map - relative XPath query to select value for every key
     */
    public ClxKey(String name, XPathExpression match, XPathExpression use) {
        super();
        this.name = name;
        this.match = match;
        this.use = use;
    }                

    /**
     * Returns key selector.
     * @return absolute XPath query to select key; !=null
     */
    public XPathExpression getMatch() {
        return match;
    }

    /**
     * Returns map name.
     * @return map name; !=null
     */
    public String getName() {
        return name;
    }
    
    /** 
     * Returns key's value selector.
     * @return relative XPath query to select value for every key; !=null
     */
    public XPathExpression getUse() {
        return use;
    }           
    
    public String toString() {
        return this.name;
    }

}
