package org.xdv.clx.extension;

import java.util.Map;

import org.xdv.clx.exec.ClxExecutionContext;
import org.xdv.clx.expr.ClxFormula;

/**
 * Inline MACRO CALL - CLX extended element implementation.
 * <p>
 * This call simply inlines formula from macro call ({@link org.xdv.clx.expr.ClxMacro}).
 * Macro definition must be known before creating this kind of call. It means that it doesn't
 * support recurrent execution or forwarding.
 * </p>
 * 
 * @author Tomasz Kokoszka
 */
public class ClxExtMacroCallInline extends ClxExtMacroCall {

    /** Inlined formula */
    private final ClxFormula inlineFormula;
    
    /**
     * Create inlined macro call.
     * @param formula inlined formula (from macro definition)
     * @param params macro parameters: parameter name-&gt;expression to evaluate its value 
     *        ({@link String}-&gt;{@link org.xdv.xpath.XPathExpression}).
     */
    public ClxExtMacroCallInline(ClxFormula formula, Map params) {
        super(params);
        this.inlineFormula = formula;
    }
    
    public String getMacroName() {
        return "inline";
    }

    /**
     * Returns macro output - formula that will executed by this macro call.
     * <br>
     * This implementation simply returns a private attribute without any additional computations.  
     * @param cntx execution context
     * @return formula to execute; !=null
     */
    protected ClxFormula getOutput(ClxExecutionContext cntx) {
        return inlineFormula;
    }        
    
    public String toString() {
        return "macroCall:inline" + super.toString() + "{" + inlineFormula + "}";
    }

}
